@@ -23,14 +23,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Version Info: $Id: chan_h323.h 227580 2009-11-04 14:05:12Z tilghman $
+ * Version Info: $Id: chan_h323.h 306010 2011-02-03 16:22:10Z dvossel $
  */
 
 #ifndef CHAN_H323_H
 #define CHAN_H323_H
 
 #include <arpa/inet.h>
-#include "asterisk/frame_defs.h"
+#include "asterisk/format.h"
 
 /*
  * Enable support for sending/reception of tunnelled Q.SIG messages and
@@ -47,6 +47,8 @@
 #define H323_HOLD_Q931ONLY	(1 << 1)
 #define H323_HOLD_H450		(1 << 2)
 
+typedef int64_t h323_format;
+
 /** call_option struct holds various bits
  *         of information for each call */
 typedef struct call_options {
@@ -65,7 +67,7 @@ typedef struct call_options {
 	int				progress_audio;
 	int				dtmfcodec[2];
 	int				dtmfmode;
-	format_t        capability;
+	h323_format     capability;
 	int				bridge;
 	int				nat;
 	int				tunnelOptions;
